@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 4739 2012-03-08 04:00:37Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 4854 2012-04-15 04:00:42Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
@@ -165,8 +165,10 @@ class ScriptLibInfo
 	//const JQUERYS_FILENAME			= 'jquery-1.5.2.min.js';					// JQuery
 	const JQUERYS_FILENAME			= 'jquery-1.6.4.min.js';					// JQuery MobileはjQuery v1.6以上が必要
 	//const JQUERYS_MOBILE_FILENAME	= 'jquery_mobile/jquery.mobile-1.0.min.js';					// JQuery Mobile
-	const JQUERYS_MOBILE_FILENAME	= 'jquery_mobile/jquery.mobile-1.0.1.min.js';					// JQuery Mobile
+//	const JQUERYS_MOBILE_FILENAME	= 'jquery_mobile/jquery.mobile-1.0.1.min.js';					// JQuery Mobile
 //	const JQUERYS_MOBILE_CSS		= 'jquery_mobile/jquery.mobile-1.0.min.css';				// JQuery Mobile
+	const JQUERYS_MOBILE_FILENAME	= 'jquery_mobile/jquery.mobile-1.1.0.min.js';					// JQuery Mobile
+	const JQUERYS_MOBILE_CSS		= 'jquery_mobile/jquery.mobile.structure-1.1.0.min.css';				// JQuery Mobile
 	
 	/**
 	 * コンストラクタ
@@ -318,8 +320,8 @@ class ScriptLibInfo
 		
 		// スマートフォン用jQueryライブラリ
 		$libs[self::LIB_JQUERYS] 			= array(	'script' => array(self::getJQueryFilename(10)));		// スマートフォン用jQuery
-		$libs[self::LIB_JQUERYS_MOBILE]		= array(	'script' 	=> array(self::JQUERYS_MOBILE_FILENAME));	// JQuery Mobile
-	//													'css'		=> array(self::JQUERYS_MOBILE_CSS));
+		$libs[self::LIB_JQUERYS_MOBILE]		= array(	'script' 	=> array(self::JQUERYS_MOBILE_FILENAME),	// JQuery Mobile
+														'css'		=> array(self::JQUERYS_MOBILE_CSS));
 														
 		return $libs;
 	}
