@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 4545 2012-01-01 12:43:10Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 4836 2012-04-10 23:52:57Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -577,15 +577,12 @@ class BaseFrameContainer extends Core
 		$this->gEnv->setCurrentTemplateId($curTemplate);
 
 		// テンプレート情報を取得
-		$convType = 0;		// 変換処理タイプ(0=デフォルト(Joomla!v1.0)、-1=携帯用、1=Joomla!v1.5)
+		$convType = 0;		// 変換処理タイプ(0=デフォルト(Joomla!v1.0)、-1=携帯用、1=Joomla!v1.5、2=Joomla!v2.5)
 		if ($this->gEnv->getIsMobileSite()){
 			$convType = -1;		// 携帯サイト用変換
 		} else {
-			// テンプレートタイプを取得(0=デフォルト(Joomla!v1.0)、1=Joomla!v1.5)
+			// テンプレートタイプを取得(0=デフォルト(Joomla!v1.0),1=Joomla!v1.5,2=Joomla!v2.5)
 			$convType = $this->gEnv->getCurrentTemplateType();
-			//if (!defined('M3_STATE_IN_INSTALL') && $this->_db->getTemplate($curTemplate, $row)){// インストールモード以外のとき
-			//	if ($row['tm_type'] == 1) $convType = 1;		// Joomla!v1.5テンプレートのとき
-			//}
 		}
 
 		// バッファリングの準備
@@ -604,7 +601,7 @@ class BaseFrameContainer extends Core
 		// サブクラスの前処理を実行
 		if (method_exists($this, '_preBuffer')) $this->_preBuffer($request);
 	
-		if ($convType == 1){		// Joomla!v1.5テンプレートのとき
+		if ($convType >= 1){		// Joomla!v1.5,v2.5テンプレートのとき
 			global $mainframe;
 			require_once($this->gEnv->getJoomlaRootPath() . '/mosDef.php');// Joomla定義読み込み
 			require_once($this->gEnv->getJoomlaRootPath() . '/JParameter.php');
@@ -666,8 +663,8 @@ class BaseFrameContainer extends Core
 		ob_clean();
 
 		// Joomla!タグの変換処理(ウィジェット実行)
-		if ($convType == 1){		// Joomla!v1.5テンプレートのとき
-			$srcContents = $this->gPage->launchWidgetByJoomlaTag($srcContents);
+		if ($convType >= 1){		// Joomla!v1.5,v2.5テンプレートのとき
+			$srcContents = $this->gPage->launchWidgetByJoomlaTag($srcContents, $convType);
 		}
 	
 		// 遅延実行ウィジェットの出力を埋め込む
