@@ -8,16 +8,17 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainConfigwidgetWidgetContainer.php 2276 2009-09-02 04:12:51Z fishbone $
+ * @version    SVN: $Id: admin_mainConfigwidgetWidgetContainer.php 4347 2011-09-24 11:39:00Z fishbone $
  * @link       http://www.magic3.org
  */
-//require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
 
 class admin_mainConfigwidgetWidgetContainer extends admin_mainBaseWidgetContainer
 {
+	const JQUERY_IFRAME_FILE = '/jquery/jquery.iframe-auto-height.plugin.1.5.0.min.js';	// jQueryプラグイン
+	
 	/**
 	 * コンストラクタ
 	 */
@@ -60,5 +61,20 @@ class admin_mainConfigwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		if (!empty($todo)) $url .= '&' . urldecode($todo);
 		$this->tmpl->addVar("_widget", "url", $url);
 	}
+	/**
+	 * JavascriptファイルをHTMLヘッダ部に設定
+	 *
+	 * JavascriptファイルをHTMLのheadタグ内に追加出力する。
+	 * _assign()よりも後に実行される。
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ。
+	 * @return string 						Javascriptファイル。出力しない場合は空文字列を設定。
+	 */
+	function _addScriptFileToHead($request, &$param)
+	{
+		$scriptArray = array($this->getUrl($this->gEnv->getScriptsUrl() . self::JQUERY_IFRAME_FILE));
+		return $scriptArray;
+	}
 }
 ?>
