@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_menuWidgetContainer.php 4833 2012-04-10 23:38:06Z fishbone $
+ * @version    SVN: $Id: default_menuWidgetContainer.php 4844 2012-04-12 06:07:55Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -134,7 +134,13 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 				$classArray = array();
 				$linkClassArray = array();
 				$attr = '';
+				// Joomla用メニューデータ
+				$addMenuItem = true;			// メニュー項目を追加するかどうか
 				$menuItem = new stdClass;		// Joomla用メニューデータ
+				$menuItem->type = 'alias';		// 内部リンク。外部リンク(url)
+				$menuItem->id = $index + 1;
+				$menuItem->level = $level + 1;
+				$menuItem->active = false;
 				
 				// 非表示のときは処理を飛ばす
 				if (!$row['md_visible']) continue;
@@ -164,6 +170,7 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 					$pathTree[] = $index + 1;
 					$this->menuData['path'] = $pathTree;
 					$this->menuData['active_id'] = $index + 1;
+					$menuItem->active = true;
 				}
 				
 				// リンクタイプに合わせてタグを生成
@@ -171,9 +178,12 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 				if (count($linkClassArray) > 0) $linkOption .= 'class="' . implode(' ', $linkClassArray) . '"';
 				switch ($row['md_link_type']){
 					case 0:			// 同ウィンドウで開くリンク
+					default:
+						$menuItem->browserNav = 0;		// ウィンドウオープン方法(0=同じウィンドウ、1=別タブ、2=別ウィンドウ)
 						break;
 					case 1:			// 別ウィンドウで開くリンク
 						$linkOption .= ' target="_blank"';
+						$menuItem->browserNav = 1;		// ウィンドウオープン方法(0=同じウィンドウ、1=別タブ、2=別ウィンドウ)
 						break;
 				}
 				
@@ -186,30 +196,19 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 						if (count($classArray) > 0) $attr .= ' class="' . implode(' ', $classArray) . '"';
 						$treeHtml .= '<li' . $attr . '><a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" ' . $linkOption . '><span>' . $this->convertToDispString($name) . '</span></a></li>' . M3_NL;
 						// Joomla用メニューデータ作成
-						$menuItem->id = $index;
+						$addMenuItem = true;			// メニュー項目を追加するかどうか
 						$menuItem->title = $name;
-						$menuItem->link = $linkUrl;
-						$menuItem->level = $level + 1;
+						$menuItem->flink = $linkUrl;
 						$menuItem->parent = false;
-						if ($hasSelectedChild){
-							$menuItem->active = true;
-						} else {
-							$menuItem->active = false;
-						}
 						break;
 					case 1:			// フォルダのとき
 						if (!empty($this->isHierMenu)){	// 階層化メニューを使用する場合
 							// Joomla用メニューデータ作成
-							$menuItem->id = $index;
+							$addMenuItem = true;			// メニュー項目を追加するかどうか
 							$menuItem->title = $name;
-							$menuItem->link = $linkUrl;
-							$menuItem->level = $level + 1;
+							$menuItem->flink = $linkUrl;
 							$menuItem->parent = true;
-							if ($hasSelectedChild){
-								$menuItem->active = true;
-							} else {
-								$menuItem->active = false;
-							}
+
 							// 階層を更新
 							array_push($parentTree, $index + 1);
 							
@@ -241,6 +240,13 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 						break;
 					case 3:			// セパレータのとき
 						$treeHtml .= '<li><span class="separator">' . $this->convertToDispString($name) . '</span></li>' . M3_NL;
+						
+						// Joomla用メニューデータ作成
+						$addMenuItem = true;			// メニュー項目を追加するかどうか
+						$menuItem->type = 'separator';
+						$menuItem->title = $name;
+						$menuItem->flink = '';
+						$menuItem->parent = false;
 						break;
 				}
 				$index++;		// インデックス番号更新
@@ -256,7 +262,7 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 					$this->tmpl->parseTemplate('itemlist', 'a');
 				}
 				// Joomla用メニュー階層
-				if (!empty($menuItem)) $this->menuTree[] = $menuItem;
+				if ($addMenuItem) $this->menuTree[] = $menuItem;
 			}
 		}
 		return $treeHtml;
